summaryrefslogtreecommitdiffstats
path: root/src/charts/layout/abstractchartlayout.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/charts/layout/abstractchartlayout.cpp')
-rw-r--r--src/charts/layout/abstractchartlayout.cpp29
1 files changed, 16 insertions, 13 deletions
diff --git a/src/charts/layout/abstractchartlayout.cpp b/src/charts/layout/abstractchartlayout.cpp
index a6c2d716..3d31dd07 100644
--- a/src/charts/layout/abstractchartlayout.cpp
+++ b/src/charts/layout/abstractchartlayout.cpp
@@ -1,12 +1,11 @@
/****************************************************************************
**
-** Copyright (C) 2021 The Qt Company Ltd.
+** Copyright (C) 2016 The Qt Company Ltd.
** Contact: https://www.qt.io/licensing/
**
** This file is part of the Qt Charts module of the Qt Toolkit.
**
-** $QT_BEGIN_LICENSE:COMM$
-**
+** $QT_BEGIN_LICENSE:GPL$
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
@@ -15,15 +14,16 @@
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
-** $QT_END_LICENSE$
-**
-**
-**
-**
-**
-**
-**
+** GNU General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU
+** General Public License version 3 or (at your option) any later version
+** approved by the KDE Free Qt Foundation. The licenses are as published by
+** the Free Software Foundation and appearing in the file LICENSE.GPL3
+** included in the packaging of this file. Please review the following
+** information to ensure the GNU General Public License requirements will
+** be met: https://www.gnu.org/licenses/gpl-3.0.html.
**
+** $QT_END_LICENSE$
**
****************************************************************************/
@@ -54,8 +54,11 @@ void AbstractChartLayout::setGeometry(const QRectF &rect)
if (!rect.isValid())
return;
- // If the chart has a fixed geometry then don't update visually
- const bool updateLayout = (!m_presenter->isFixedGeometry() || m_presenter->geometry() == rect);
+ // If the chart has a fixed geometry then don't update visually, unless plotbackground is
+ // visible.
+ const bool updateLayout = (!m_presenter->isFixedGeometry()
+ || m_presenter->isPlotAreaBackgroundVisible()
+ || m_presenter->geometry() == rect);
if (m_presenter->chart()->isVisible()) {
QList<ChartAxisElement *> axes = m_presenter->axisItems();
ChartTitle *title = m_presenter->titleElement();